@@ -2,7 +2,7 @@
 edgeRranking <- function(countsTrain, classesTrain, normFactorsOptions = NULL, dispOptions = NULL, fitOptions = NULL, verbose = 3)
 {
   if(verbose == 3)
-    message("Doing edgeR LRT feature ranking")
+    message(Sys.time(), ": Doing edgeR LRT feature ranking")
   if(!requireNamespace("edgeR", quietly = TRUE))
     stop("The package 'edgeR' could not be found. Please install it.")
   
@@ -12,19 +12,19 @@ edgeRranking <- function(countsTrain, classesTrain, normFactorsOptions = NULL, d
   if(!is.null(normFactorsOptions))
     paramList <- append(paramList, normFactorsOptions)
   if(verbose == 3)
-    message("Calculating scaling factors.")
+    message(Sys.time(), ": Calculating scaling factors.")
   countsList <- do.call(edgeR::calcNormFactors, paramList)
   paramList <- list(countsList, model.matrix(~ classesTrain))
   if(!is.null(dispOptions))
     paramList <- append(paramList, dispOptions)
   if(verbose == 3)
-    message("Estimating dispersion.")
+    message(Sys.time(), ": Estimating dispersion.")
   countsList <- do.call(edgeR::estimateDisp, paramList)
   paramList <- list(countsList, model.matrix(~ classesTrain))
   if(!is.null(fitOptions))
     paramList <- append(paramList, fitOptions)
   if(verbose == 3)
-    message("Fitting linear model.")
+    message(Sys.time(), ": Fitting linear model.")
   fit <- do.call(edgeR::glmFit, paramList)
   test <- edgeR::glmLRT(fit, coef = 2:length(levels(classesTrain)))[["table"]]
   
